nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

IntEnable

Struct IntEnable 

#[repr(transparent)]
pub struct IntEnable(pub u32);
Interrupt enable bits

Tuple Fields

0: u32

Implementations

Source

impl IntEnable

pub const fn fail(&self) -> bool

If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.

pub const fn set_fail(&mut self, val: bool)

If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.

pub const fn err(&self) -> bool

If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.

pub const fn set_err(&mut self, val: bool)

If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.

pub const fn done(&self) -> bool

If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.

pub const fn set_done(&mut self, val: bool)

If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.

pub const fn ecc_err(&self) -> bool

If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.

pub const fn set_ecc_err(&mut self, val: bool)

If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.