nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

IntStatus

Struct IntStatus 

#[repr(transparent)]
pub struct IntStatus(pub u32);
Interrupt status bits

Tuple Fields

0: u32

Implementations

Source

impl IntStatus

pub const fn fail(&self) -> bool

This status bit is set if execution of a (legal) command failed.

pub const fn set_fail(&mut self, val: bool)

This status bit is set if execution of a (legal) command failed.

pub const fn err(&self) -> bool

This status bit is set if execution of an illegal command is detected.

pub const fn set_err(&mut self, val: bool)

This status bit is set if execution of an illegal command is detected.

pub const fn done(&self) -> bool

This status bit is set at the end of command execution.

pub const fn set_done(&mut self, val: bool)

This status bit is set at the end of command execution.

pub const fn ecc_err(&self) -> bool

This status bit is set if, during a memory read operation (either a user-requested read, or a speculative read, or reads performed by a controller command), a correctable or uncorrectable error is detected by ECC decoding logic.

pub const fn set_ecc_err(&mut self, val: bool)

This status bit is set if, during a memory read operation (either a user-requested read, or a speculative read, or reads performed by a controller command), a correctable or uncorrectable error is detected by ECC decoding logic.