#[repr(transparent)]pub struct IntStatus(pub u32);Expand description
Interrupt status bits
Tuple Fields
0: u32Implementations
Sourceimpl IntStatus
impl IntStatus
Sourcepub const fn fail(&self) -> bool
pub const fn fail(&self) -> bool
This status bit is set if execution of a (legal) command failed.
Sourcepub const fn set_fail(&mut self, val: bool)
pub const fn set_fail(&mut self, val: bool)
This status bit is set if execution of a (legal) command failed.
Sourcepub const fn err(&self) -> bool
pub const fn err(&self) -> bool
This status bit is set if execution of an illegal command is detected.
Sourcepub const fn set_err(&mut self, val: bool)
pub const fn set_err(&mut self, val: bool)
This status bit is set if execution of an illegal command is detected.
Sourcepub const fn set_done(&mut self, val: bool)
pub const fn set_done(&mut self, val: bool)
This status bit is set at the end of command execution.
Sourcepub const fn ecc_err(&self) -> bool
pub const fn ecc_err(&self) -> bool
This status bit is set if, during a memory read operation (either a user-requested read, or a speculative read, or reads performed by a controller command), a correctable or uncorrectable error is detected by ECC decoding logic.
Sourcepub const fn set_ecc_err(&mut self, val: bool)
pub const fn set_ecc_err(&mut self, val: bool)
This status bit is set if, during a memory read operation (either a user-requested read, or a speculative read, or reads performed by a controller command), a correctable or uncorrectable error is detected by ECC decoding logic.